"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.performAudit = void 0;
const execa_1 = require("execa");
const const_1 = require("./const");
const deps_1 = require("./deps");
const fs_1 = require("./fs");
const defaultAuditResult = {
    message: 'Audit performed successfully. No issues were found.',
    exitCode: 0,
};
async function performAudit(auditor) {
    const temps = await fs_1.createTempLocations();
    const packageJSON = await deps_1.globalPackageJSON('npm');
    await fs_1.saveMinimalPackageJSON(temps.packageJSON, packageJSON);
    switch (auditor) {
        case 'yarn':
            return runWithYarn(temps.tmpDir);
        case 'npm':
            return runWithNPM(temps.tmpDir);
        default:
            return defaultAuditResult;
    }
}
exports.performAudit = performAudit;
async function runWithYarn(cwd) {
    var _a;
    const auditResult = Object.assign(Object.assign({}, defaultAuditResult), { message: 'Audit performed successfully. No issues were found.', exitCode: 0 });
    try {
        await execa_1.command('npx yarn install', { stdin: 'inherit', stdout: 'inherit', stderr: 'pipe', cwd });
        await execa_1.command('npx yarn audit -y', { stdin: 'inherit', stdout: 'inherit', stderr: 'pipe', cwd });
    }
    catch (error) {
        if ((_a = error === null || error === void 0 ? void 0 : error.message) === null || _a === void 0 ? void 0 : _a.includes('refers to a non-existing file')) {
            auditResult.exitCode = const_1.ERROR_YARN_RELATIVE_FILES;
            auditResult.message =
                'Encountered a global package defined with relative `file:` protocol dependencies which is known to cause issues for yarn when performing an audit. See https://github.com/yarnpkg/yarn/issues/5735 for more. You can retry the audit using `npm` as the auditor by passing the --auditor=npm flag.';
        }
        else {
            auditResult.exitCode = const_1.ERROR_AUDIT_FAILED;
            auditResult.message = `A module audit found issues. The error level mask was [${error === null || error === void 0 ? void 0 : error.exitCode}] - See https://classic.yarnpkg.com/en/docs/cli/audit/#toc-yarn-audit for more.`;
        }
    }
    finally {
        await fs_1.pruneTempLocation();
    }
    return auditResult;
}
async function runWithNPM(cwd) {
    const auditResult = Object.assign(Object.assign({}, defaultAuditResult), { message: 'Audit performed successfully. No issues were found.', exitCode: 0 });
    try {
        await execa_1.command('npm install', { stdin: 'inherit', stdout: 'inherit', stderr: 'pipe', cwd });
        await execa_1.command('npm audit', { stdin: 'inherit', stdout: 'inherit', stderr: 'pipe', cwd });
    }
    catch (error) {
        auditResult.exitCode = const_1.ERROR_AUDIT_FAILED;
        auditResult.message = `A module audit found issues.`;
    }
    finally {
        await fs_1.pruneTempLocation();
    }
    return auditResult;
}
